@@ -10,28 +10,32 @@ from click.exceptions import ClickException
 from . import __version__
 from .repository.materials import MaterialRepository
 
-workingDir = pathlib.Path(".")
-repo = MaterialRepository(workingDir)
+from .env import env
 
 
 def setWorkingDirectory(wdir: pathlib.Path):
-    global workingDir, repo
-    workingDir = wdir
-    repo = MaterialRepository(workingDir)
+    env.setPath(wdir)
 
 
 @click.command()
-@click.option("-P", "--port", default=3649, help="Port to bind.")
-def serve(port: int = 3649) -> None:
+def serve() -> None:
     """Serve websites."""
-    from .server import run
-    run.run(repo, port=port)
+    from .server import entrypoint
+    entrypoint.serve()
+
+
+@click.command()
+@click.option("-P", "--py", is_flag=True, default=False, help="Create simple server python script.")
+def build(py: bool = False) -> None:
+    """Build static website."""
+    from .server import entrypoint
+    entrypoint.build(py)
 
 
 @click.command()
 @click.argument("id")
 def new(id: str) -> None:
-    repo.create(id)
+    env.repo.create(id)
 
 
 @click.command()
@@ -40,10 +44,10 @@ def new(id: str) -> None:
 def new(id: str, note: str = "") -> None:
     """Create a new material or note."""
     if note:
-        if id not in repo:
+        if id not in env.repo:
             raise ClickException(f"Not found material with id '{id}'.")
 
-        material = repo[id]
+        material = env.repo[id]
         if note in material.notes:
             raise ClickException(
                 f"Note with id '{note}' exists for material with id '{id}'.")
@@ -53,10 +57,10 @@ def new(id: str, note: str = "") -> None:
         click.echo(
             f"Created note with id '{note}' for material with id '{id}'.")
     else:
-        if id in repo:
+        if id in env.repo:
             raise ClickException(f"Material with id '{id}' exists.")
 
-        repo.create(id)
+        env.repo.create(id)
 
         click.echo(f"Created material with id '{id}'.")
 
@@ -68,10 +72,10 @@ def rm(id: str, note: str = "") -> None:
     """Remove a material or note."""
 
     if note:
-        if id not in repo:
+        if id not in env.repo:
             raise ClickException(f"Not found material with id '{id}'.")
 
-        material = repo[id]
+        material = env.repo[id]
         if note not in material.notes:
             raise ClickException(
                 f"Not found note with id '{note}' for material with id '{id}'.")
@@ -81,10 +85,10 @@ def rm(id: str, note: str = "") -> None:
         click.echo(
             f"Removed note with id '{note}' for material with id '{id}'.")
     else:
-        if id not in repo:
+        if id not in env.repo:
             raise ClickException(f"Not found material with id '{id}'.")
 
-        del repo[id]
+        del env.repo[id]
 
         click.echo(f"Removed material with id '{id}'.")
 
@@ -96,15 +100,15 @@ def list(id: str = "") -> None:
     """List materials and notes."""
 
     if id:
-        if id not in repo:
+        if id not in env.repo:
             raise ClickException(f"Not found material with id '{id}'.")
 
-        material = repo[id]
+        material = env.repo[id]
 
         for item in material.notes:
             click.echo(item)
     else:
-        for item in repo:
+        for item in env.repo:
             click.echo(item)
 
 
@@ -134,7 +138,7 @@ def main(ctx=None, directory: pathlib.Path = ".", verbose: int = 0, version: boo
 
     logger.debug(f"Logging level: {loggingLevel}")
 
-    logger.info(f"Working directory: {click.format_filename(workingDir)}")
+    logger.info(f"Working directory: {click.format_filename(env.path)}")
 
     if version:
         click.echo(f"Paperead v{__version__}")
@@ -142,6 +146,7 @@ def main(ctx=None, directory: pathlib.Path = ".", verbose: int = 0, version: boo
 
 
 main.add_command(serve)
+main.add_command(build)
 main.add_command(new)
 main.add_command(rm)
 main.add_command(list)
