@@ -3,4 +3,4 @@ from .. import app
 
 @app.route("/api")
 def hello_world():
-    return "<p>Hello, World!</p>"
+    return "<p>Hello, Peperead API!</p>"
